==> xml-soap_2.2.orig.tar.gz: xml-soap-2.2.orig/src/org/apache/soap/util/xml/QName.java <==
/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2000 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "SOAP" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation and was
 * originally based on software copyright (c) 2000, International
 * Business Machines, Inc., http://www.apache.org.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

package org.apache.soap.util.xml;

import org.w3c.dom.Node;

/**
 * A <code>QName</code> represents a fully-qualified name.
 *
 * @author Matthew J. Duftler (duftler@us.ibm.com)
 * @author Sanjiva Weerawarana (sanjiva@watson.ibm.com)
 */
public class QName implements java.io.Serializable
{
  private String namespaceURI;
  private String localPart;

  public QName()
  {
    // no args constructor for use as bean
  }

  public QName(Node node) throws IllegalArgumentException
  {
    String namespaceURI = node.getNamespaceURI();

    if (namespaceURI == null)
    {
      throw new IllegalArgumentException("Can't create QName: NamespaceURI " +
                                         "must not be null.");
    }

    String localPart = node.getLocalName();

    if (localPart == null)
    {
      throw new IllegalArgumentException("Can't create QName: LocalName " +
                                         "must not be null.");
    }

    setNamespaceURI(namespaceURI);
    setLocalPart(localPart);
  }

  public QName(String namespaceURI, String localPart)
  {
    setNamespaceURI(namespaceURI);
    setLocalPart(localPart);
  }
  
  public void setNamespaceURI(String namespaceURI)
  {
    this.namespaceURI = (namespaceURI == null ? "" : namespaceURI).intern();
  }

  public String getNamespaceURI()
  {
    return namespaceURI;
  }

  public void setLocalPart(String localPart)
  {
    this.localPart = localPart.intern();
  }

  public String getLocalPart()
  {
    return localPart;
  }

  public int hashCode()
  {
    String hash1 = namespaceURI.hashCode() + "";
    String hash2 = localPart.hashCode() + "";
    String hash3 = hash1 + '_' + hash2;

    return hash3.hashCode();
  }

  public boolean equals(Object obj)
  {
    return (obj != null
            && namespaceURI == ((QName)obj).getNamespaceURI()
            && localPart == ((QName)obj).getLocalPart());
  }

  public boolean matches(Node node)
  {
    try
    {
      return (node != null && this.equals(new QName(node)));
    }
    catch (IllegalArgumentException e)
    {
      return false;
    }
  }

  public String toString()
  {
    return namespaceURI + ':' + localPart;
  }
}

==> xml-soap_2.3.1.orig.tar.gz: xml-soap-2.3.1.orig/src/org/apache/soap/util/xml/QName.java <==
/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2000 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "SOAP" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation and was
 * originally based on software copyright (c) 2000, International
 * Business Machines, Inc., http://www.apache.org.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

package org.apache.soap.util.xml;

import org.w3c.dom.Node;

/**
 * A <code>QName</code> represents a fully-qualified name.
 *
 * @author Matthew J. Duftler (duftler@us.ibm.com)
 * @author Sanjiva Weerawarana (sanjiva@watson.ibm.com)
 */
public class QName implements java.io.Serializable
{
  private String namespaceURI;
  private String localPart;

  public QName()
  {
    // no args constructor for use as bean
  }

  public QName(Node node) throws IllegalArgumentException
  {
    String namespaceURI = node.getNamespaceURI();

    if (namespaceURI == null)
    {
      throw new IllegalArgumentException("Can't create QName: NamespaceURI " +
                                         "must not be null.");
    }

    String localPart = node.getLocalName();

    if (localPart == null)
    {
      throw new IllegalArgumentException("Can't create QName: LocalName " +
                                         "must not be null.");
    }

    setNamespaceURI(namespaceURI);
    setLocalPart(localPart);
  }

  public QName(String namespaceURI, String localPart)
  {
    setNamespaceURI(namespaceURI);
    setLocalPart(localPart);
  }
  
  public void setNamespaceURI(String namespaceURI)
  {
    this.namespaceURI = (namespaceURI == null ? "" : namespaceURI).intern();
  }

  public String getNamespaceURI()
  {
    return namespaceURI;
  }

  public void setLocalPart(String localPart)
  {
    this.localPart = (localPart == null ? "" : localPart).intern();
  }

  public String getLocalPart()
  {
    return localPart;
  }

  public int hashCode()
  {
    String hash1 = namespaceURI.hashCode() + "";
    String hash2 = localPart.hashCode() + "";
    String hash3 = hash1 + '_' + hash2;

    return hash3.hashCode();
  }

  public boolean equals(Object obj)
  {
    return (obj != null
            && namespaceURI == ((QName)obj).getNamespaceURI()
            && localPart == ((QName)obj).getLocalPart());
  }

  public boolean matches(Node node)
  {
    try
    {
      return (node != null && this.equals(new QName(node)));
    }
    catch (IllegalArgumentException e)
    {
      return false;
    }
  }

  public String toString()
  {
    return namespaceURI + ':' + localPart;
  }
}
